# straxen
Streaming analysis for XENON(nT)

[![Build Status](https://travis-ci.org/XENONnT/straxen.svg?branch=master)](https://travis-ci.org/XENONnT/straxen)
[![Test package](https://github.com/XENONnT/straxen/workflows/Test%20package/badge.svg?branch=master)](https://github.com/XENONnT/straxen/actions?query=branch%3Amaster)
[![PyPI version shields.io](https://img.shields.io/pypi/v/straxen.svg)](https://pypi.python.org/pypi/straxen/)
[![Readthedocs Badge](https://readthedocs.org/projects/straxen/badge/?version=latest)](https://straxen.readthedocs.io/en/latest/?badge=latest)
[![CodeFactor](https://www.codefactor.io/repository/github/xenonnt/straxen/badge)](https://www.codefactor.io/repository/github/xenonnt/straxen)
[![Coverage Status](https://coveralls.io/repos/github/XENONnT/straxen/badge.svg)](https://coveralls.io/github/XENONnT/straxen)
![Update context collection](https://github.com/XENONnT/straxen/workflows/Update%20context%20collection/badge.svg)
[![Join the chat at https://gitter.im/AxFoundation/strax](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/AxFoundation/strax?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)


Straxen is the analysis framework for XENONnT, built on top of the generic [strax framework](https://github.com/AxFoundation/strax). Currently it is configured for analyzing XENON1T data.

For installation instructions and usage information, please see the [straxen documentation](https://straxen.readthedocs.io).
